pub struct UdpSession<T, C>where
T: Initiator<Connection = C>,
C: Connection,{ /* private fields */ }Expand description
A virtual UDP session that provides a socket-like API.
When this struct is dropped, its session is automatically cleaned up on the client side to prevent resource leaks.
Implementations