Module ffi

Module ffi 

Functions

ombrac_client_get_version
Returns the version of the ombrac-client library.
ombrac_client_service_rebind
Triggers a network rebind on the underlying transport.
ombrac_client_service_shutdown
Shuts down the running service and releases all associated resources.
ombrac_client_service_startup
Initializes and starts the service with a given JSON configuration.
ombrac_client_set_log_callback
Initializes the logging system to use a C-style callback for log messages.