pub fn set_log_callback(callback: Option<LogCallback>)Expand description
Sets or clears the global log callback for FFI.
This function should be called before init_for_ffi.
pub fn set_log_callback(callback: Option<LogCallback>)Sets or clears the global log callback for FFI.
This function should be called before init_for_ffi.