Functions
- ombrac_
client_ get_ version - Returns the version of the ombrac-client library.
- ombrac_
client_ service_ rebind - Triggers a network rebind on the underlying transport.
- ombrac_
client_ service_ shutdown - Shuts down the running service and releases all associated resources.
- ombrac_
client_ ⚠service_ startup - Initializes and starts the service with a given JSON configuration.
- ombrac_
client_ ⚠set_ log_ callback - Initializes the logging system to use a C-style callback for log messages.